===========
Ansible 2.8
===========

.. contents::
   :local:

Release Schedule
----------------

Expected
========

PRs must be raised well in advance of the dates below to have a chance of being included in this Ansible release.

- 2019-04-04 Alpha 1 **Core freeze**
  No new features to ``support:core`` code.
  Includes no new options to existing Core modules

- 2019-04-11 Beta 1 **Feature freeze**
  No new functionality (including modules/plugins) to any code

- 2019-04-25 Release Candidate 1
- 2019-05-02 Release Candidate 2
- 2019-05-10 Release Candidate 3
- 2019-05-16 Release



Release Manager
---------------

Toshio Kuratomi (IRC: abadger1999; GitHub: @abadger)

Planned work
============

See the `Ansible 2.8 Project Board <https://github.com/ansible/ansible/projects/30>`_
